@@ -20,6 +20,10 @@ class AsyncSentryClient(Client):
     asynchronously send errors to sentry. The client also captures the
     information from the request handlers
     """
+    def __init__(self, *args, **kwargs):
+        self.validate_cert = kwargs.pop('validate_cert', True)
+        super(AsyncSentryClient, self).__init__(*args, **kwargs)
+
     def capture(self, *args, **kwargs):
         """
         Takes the same arguments as the super function in :py:class:`Client`
@@ -35,7 +39,7 @@ class AsyncSentryClient(Client):
 
         self.send(callback=kwargs.get('callback', None), **data)
 
-        return (data['event_id'], data['checksum'])
+        return (data['event_id'],)
 
     def send(self, auth_header=None, callback=None, **data):
         """
@@ -84,7 +88,7 @@ class AsyncSentryClient(Client):
             self._send_remote(
                 url=url, data=data, headers=headers, callback=callback
             )
-        except HTTPError, e:
+        except HTTPError as e:
             body = e.response.body
             self.error_logger.error(
                 'Unable to reach Sentry log server: %s '
@@ -92,7 +96,7 @@ class AsyncSentryClient(Client):
                 url, body, exc_info=True,
                 extra={'data': {'body': body, 'remote_url': url}}
             )
-        except Exception, e:
+        except Exception as e:
             self.error_logger.error(
                 'Unable to reach Sentry log server: %s (url: %%s)' % (e,),
                 url, exc_info=True, extra={'data': {'remote_url': url}}
@@ -113,7 +117,8 @@ class AsyncSentryClient(Client):
             headers = {}
 
         return AsyncHTTPClient().fetch(
-            url, callback, method="POST", body=data, headers=headers
+            url, callback, method="POST", body=data, headers=headers,
+            validate_cert=self.validate_cert
         )
 
 
@@ -130,8 +135,8 @@ class SentryMixin(object):
             def get(self):
                 try:
                     fail()
-                except Exception, e:
-                    self.captureException(sys.exc_info())
+                except Exception as e:
+                    self.captureException()
 
 
     While the above example would result in sequential execution, an example
@@ -178,7 +183,7 @@ class SentryMixin(object):
             'sentry.interfaces.Http': {
                 'url': self.request.full_url(),
                 'method': self.request.method,
-                'data': self.request.arguments,
+                'data': self.request.body,
                 'query_string': self.request.query,
                 'cookies': self.request.headers.get('Cookie', None),
                 'headers': dict(self.request.headers),
@@ -244,9 +249,22 @@ class SentryMixin(object):
     def captureMessage(self, message, **kwargs):
         return self._capture('captureMessage', message=message, **kwargs)
 
-    def write_error(self, status_code, **kwargs):
+    def log_exception(self, typ, value, tb):
         """Override implementation to report all exceptions to sentry.
+        log_exception() is added in Tornado v3.1.
         """
-        rv = super(SentryMixin, self).write_error(status_code, **kwargs)
-        self.captureException(exc_info=kwargs['exc_info'])
+        rv = super(SentryMixin, self).log_exception(typ, value, tb)
+        self.captureException(exc_info=(typ, value, tb))
         return rv
+
+    def send_error(self, status_code=500, **kwargs):
+        """Override implementation to report all exceptions to sentry, even
+        after self.flush() or self.finish() is called, for pre-v3.1 Tornado.
+        """
+        if hasattr(super(SentryMixin, self), 'log_exception'):
+            return super(SentryMixin, self).send_error(status_code, **kwargs)
+        else:
+            rv = super(SentryMixin, self).send_error(status_code, **kwargs)
+            if 500 <= status_code <= 599:
+                self.captureException(exc_info=kwargs.get('exc_info'))
+            return rv
