@@ -1,13 +1,18 @@
 """
-This demonstrates how to implement your own transport for Raven.
+raven.contrib.transports.zeromq.raven_zmq
+~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
+
+:copyright: (c) 2010-2013 by the Sentry Team, see AUTHORS for more details
+:license: BSD, see LICENSE for more details
 """
+from __future__ import absolute_import
 
 from raven.transport import Transport
 
 import json
 
 
-class MissingLibrary(StandardError):
+class MissingLibrary(Exception):
     pass
 
 try:
